pub struct ExtensionContentProvider<S> { /* private fields */ }Expand description
Dispatches to another provider based on the file extension.
Lets one package mix source formats, for example a text language importing a serialized module.
Implementations
Sourceimpl<S> ExtensionContentProvider<S>
impl<S> ExtensionContentProvider<S>
Sourcepub fn default_extension(self, extension: impl ToString) -> Self
pub fn default_extension(self, extension: impl ToString) -> Self
Sets the extension to assume for paths that carry none.
Sourcepub fn extension(
self,
extension: &str,
content_provider: impl ScriptContentProvider<S> + 'static,
) -> Self
pub fn extension( self, extension: &str, content_provider: impl ScriptContentProvider<S> + 'static, ) -> Self
Routes one extension to a provider.